aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-dcerpc.c
diff options
context:
space:
mode:
authorsahlberg <sahlberg@f5534014-38df-0310-8fa8-9805f1628bb7>2005-07-13 08:00:15 +0000
committersahlberg <sahlberg@f5534014-38df-0310-8fa8-9805f1628bb7>2005-07-13 08:00:15 +0000
commita62ec60a50102a335671b7009725f0f7ead2e21f (patch)
tree7a31798f79e059a97f396489b6dfbdfbb6a984a2 /epan/dissectors/packet-dcerpc.c
parent5a25e5a9c61d423dd318f06709bd79f07be91454 (diff)
make idl2eth generate FT_GUID hf fields for uuid_t and GUID types.
make dissect_dcerpc_uuid_t() accept eitehr FT_STRING (old style) and FT_GUID (new style) hf fields. once all dissectors are modified to use FT_GUID we can remove the FT_STRING support here. regenerate the DRSUAPI interface with the new FT_GUID support. git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@14912 f5534014-38df-0310-8fa8-9805f1628bb7
Diffstat (limited to 'epan/dissectors/packet-dcerpc.c')
-rw-r--r--epan/dissectors/packet-dcerpc.c15
1 files changed, 11 insertions, 4 deletions
diff --git a/epan/dissectors/packet-dcerpc.c b/epan/dissectors/packet-dcerpc.c
index 6c612fbe7b..220095290d 100644
--- a/epan/dissectors/packet-dcerpc.c
+++ b/epan/dissectors/packet-dcerpc.c
@@ -1132,15 +1132,22 @@ dissect_dcerpc_uuid_t (tvbuff_t *tvb, gint offset, packet_info *pinfo _U_,
uuid.Data4[6], uuid.Data4[7]);
} else {
#endif
- /* we don't know the name of this uuid */
- proto_tree_add_string_format (tree, hfindex, tvb, offset, 16, "",
- "%s: %08x-%04x-%04x-%02x%02x-%02x%02x%02x%02x%02x%02x",
- hfi->name,
+ /* GUID have changed from FT_STRING to FT_GUID
+ but we havent changed all dissectors yet.
+ */
+ if(hfi->type==FT_GUID){
+ proto_tree_add_item(tree, hfindex, tvb, offset, 16, (drep[0] & 0x10));
+ } else {
+ /* we don't know the name of this uuid */
+ proto_tree_add_string_format (tree, hfindex, tvb, offset, 16, "",
+ "%s: %08x-%04x-%04x-%02x%02x-%02x%02x%02x%02x%02x%02x",
+ hfi->name,
uuid.Data1, uuid.Data2, uuid.Data3,
uuid.Data4[0], uuid.Data4[1],
uuid.Data4[2], uuid.Data4[3],
uuid.Data4[4], uuid.Data4[5],
uuid.Data4[6], uuid.Data4[7]);
+ }
#if 0
}
#endif